#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_nekrobox
------------

Tests for `nekrobox` module.
"""

import os
import shutil
import unittest

from nekrobox import nekrobox


class TestNekrobox(unittest.TestCase):

    def setUp(self):
        pass

    def test_something(self):
        pass

    def tearDown(self):
        pass

if __name__ == '__main__':
    unittest.main()